package com.xkrs.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;
import com.xkrs.common.encapsulation.PromptMessageEnum;
import com.xkrs.model.vo.GaoDeIgGeocodeVo;
import com.xkrs.model.vo.GaoDeWeatherVo;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.web.bind.annotation.*;

import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;
import java.util.List;
import java.util.Locale;

import static com.xkrs.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;
import static com.xkrs.utilsnew.CommonConstant.*;
import static com.xkrs.utilsold.HttpClientUtils.sendHttpsGet;

/**
 * @author wudong
 * @date 2022/5/6 16:13
 * @description 高德api接口
 */
@RestController
@RequestMapping(value = "/gaode")
public class GaoDeApiController {
    private static final Logger log = LoggerFactory.getLogger(GaoDeApiController.class);
    Locale locale = LocaleContextHolder.getLocale();

    @RequestMapping(value = "/weather", method = RequestMethod.GET)
    public String weather(@RequestParam("code") String code) {
        if (code.length() < 6) {
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"编码格式错误", locale);
        }
        if (code.length() > 6) {
            code = code.substring(0, 6);
        }
        String url = WEATHER_URL + "?key=" + WEATHER_KEY + "&extensions=all&city=" + code;
        try {
            String res = sendHttpsGet(url);
            GaoDeWeatherVo gaoDeWeatherVo = JSON.parseObject(res, new TypeReference<>(){});
            return outputEncapsulationObject(PromptMessageEnum.SUCCESS, gaoDeWeatherVo, locale);
        } catch (Exception e) {
            log.error("获取高德天气失败， {}", e.getMessage());
        }
        return outputEncapsulationObject(PromptMessageEnum.PROCESS_FAIL, "获取高德天气失败", locale);
    }

    /**
     * 逆地理编码
     * @param location
     * @return
     */
    @RequestMapping(value = "/ig", method = RequestMethod.POST)
    public String geocode(@RequestBody List<String> location) {
        if (location.size() == 0) {
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"格式错误", locale);
        }
        StringBuilder sb = new StringBuilder();
        for (String var :
                location) {
            sb.append(var).append("|");
        }
        String url = INVERSEGEOGRAPHY_URL + "?key=" + INVERSEGEOGRAPHY_KEY + "&radius=1000&extensions=all&batch=true&roadlevel=0&location=";
        try {
            String encode = URLEncoder.encode(sb.toString(), StandardCharsets.UTF_8);
            String res = sendHttpsGet(url + encode);
            GaoDeIgGeocodeVo gaoDeIgGeocodeVo = JSON.parseObject(res, GaoDeIgGeocodeVo.class);
            return outputEncapsulationObject(PromptMessageEnum.SUCCESS, gaoDeIgGeocodeVo, locale);
        } catch (Exception e) {
            log.error("获取高德天气失败， {}", e.getMessage());
        }
        return outputEncapsulationObject(PromptMessageEnum.PROCESS_FAIL, "获取高德天气失败", locale);
    }

}
